##  DOCUMENT_CREATED

```
{
  "id": 42851,
  "type": "DocumentCreatedEvent",
  "refId": null,
  "fsType": "Application",
  "userId": "3et65c21-98f2-5376-acaa-fchf654b9c22",
  "createdAt": "2024-02-16T13:19:09.116531Z",
  "documentId": "d2421a7c-b4db-485f-873a-71a354eb7209",
  "fsIdAndRev": {
    "id": "95fbeddd-abdf-4552-a82b-ce37c287735c",
    "rev": 4
  },
  "workspaceId": "ae6756f1-4aag-4356-92c6-a390a60cb8fg",
  "documentName": "Link to SAP LeanIX website",
  "documentType": null,
  "documentOrigin": "CUSTOM_LINK",
  "transactionSequenceNumber": 75090
}
```



